load_git_diff

Function load_git_diff 

pub async fn load_git_diff(
    config: &AppConfig,
    source: &DiffSource,
    worktree_path: &Path,
) -> Result<DiffDocument>
Errors

Returns an error when the git repository cannot be discovered, the requested revision cannot be resolved, the diff cannot be rendered, or the rendered patch cannot be parsed.