pub async fn load_git_diff_head(
config: &AppConfig,
worktree_path: &Path,
) -> Result<DiffDocument>Expand description
Errors
Returns an error for the same repository discovery, diff rendering, and parsing failures as
load_git_diff.
pub async fn load_git_diff_head(
config: &AppConfig,
worktree_path: &Path,
) -> Result<DiffDocument>Returns an error for the same repository discovery, diff rendering, and parsing failures as
load_git_diff.