load_root_directory_file

Function load_root_directory_file 

pub async fn load_root_directory_file(
    config: &AppConfig,
    relative_path: String,
    worktree_path: &Path,
) -> Result<Option<DiffFile>>
Errors

Returns an error when the git repository cannot be discovered, the path cannot be inspected, or the file cannot be read.