pub async fn load_root_directory_file_list(
config: &AppConfig,
) -> Result<DiffDocument>Expand description
Errors
Returns an error when the git repository cannot be discovered or root paths cannot be listed.
pub async fn load_root_directory_file_list(
config: &AppConfig,
) -> Result<DiffDocument>Returns an error when the git repository cannot be discovered or root paths cannot be listed.