discover_workdir

Function discover_workdir 

pub async fn discover_workdir(start_dir: impl AsRef<Path>) -> Result<PathBuf>
Errors

Returns an error when git repository discovery fails, the repository is bare, or the blocking discovery task cannot be joined.