BreakerState

Struct BreakerState 

pub struct BreakerState { /* private fields */ }
The mutable state of the line breaker.

This is exposed so that callers using BreakLines directly can inspect and adjust line geometry between calls to BreakLines::break_next.

A BreakerState can be cloned and later passed to BreakLines::revert_to to retry layout from a saved checkpoint.

Implementations

Source

impl BreakerState

pub fn append_cluster_to_line(&mut self, next_x: f32, clusters_height: f32)

Add the cluster(s) currently being evaluated to the current line

pub fn append_inline_box_to_line(&mut self, next_x: f32, box_height: f32)

Add inline box to line

pub fn layout_max_advance(&self) -> f32

Get the max-advance of the entire layout

pub fn set_layout_max_advance(&mut self, advance: f32)

Set the max-advance of the entire layout

pub fn line_max_advance(&self) -> f32

Get the max-advance of the current line

pub fn set_line_max_advance(&mut self, advance: f32)

Set the max-advance of the current line

pub fn line_max_height(&self) -> f32

Get the max-height of the current line

pub fn set_line_max_height(&mut self, height: f32)

Set the max-height of the current line.

pub fn line_x(&self) -> f32

Get the x-offset of the current line

pub fn set_line_x(&mut self, x: f32)

Set the x-offset for the current line.

pub fn line_y(&self) -> f64

Get the y-offset of the current line

pub fn set_line_y(&mut self, y: f64)

Set the y-offset for the current line.