Line

Struct Line 

pub struct Line<'a, B: Brush> { /* private fields */ }
Line in a text layout.

Implementations

Source

impl<'a, B: Brush> Line<'a, B>

pub fn metrics(&self) -> &LineMetrics

Returns the metrics for the line.

pub fn break_reason(&self) -> BreakReason

pub fn text_range(&self) -> Range<usize>

Returns the range of text for the line.

pub fn len(&self) -> usize

Returns the number of items in the line.

pub fn is_empty(&self) -> bool

Returns true if the line is empty.

pub fn runs(&self) -> impl Iterator<Item = Run<'a, B>> + 'a + Clone

Returns an iterator over the runs for the line.

pub fn items( &self, ) -> impl Iterator<Item = PositionedLayoutItem<'a, B>> + 'a + Clone

Returns an iterator over the glyph runs for the line.