pub enum InlineBoxKind {
InFlow,
OutOfFlow,
CustomOutOfFlow,
}Expand description
Whether a box is in-flow (takes up space in the layout) or out-of-flow (e.g. absolutely positioned) or custom-out-of-flow (line-breaking should yield control flow)
Variants
InFlow
InFlow boxes take up space in the layout and flow in line with text
They correspond to display: inline-block boxes in CSS.
OutOfFlow
OutOfFlow boxes are assigned a position as if they were a zero-sized inline box, but
do not take up space in the layout.
They correspond to position: absolute boxes in CSS.
CustomOutOfFlow
CustomOutOfFlow boxes also do not take up space in the layout, but they are not assigned a position
by Parley. When they are encountered, control flow is yielded back to the caller who is then responsible
for laying out the box.
They can be used to implement advanced layout modes such as CSS’s float